==> ember-1.3.tar.gz: ember-1.3/src/ember/emb_test.c <==
/*
** Copyright (c) 2001  Hughes Technologies Pty Ltd.  All rights
** reserved.  
**
** Terms under which this software may be used or copied are
** provided in the  specific license associated with this product.
**
** Hughes Technologies disclaims all warranties with regard to this 
** software, including all implied warranties of merchantability and 
** fitness, in no event shall Hughes Technologies be liable for any 
** special, indirect or consequential damages or any damages whatsoever 
** resulting from loss of use, data or profits, whether in an action of 
** contract, negligence or other tortious action, arising out of or in 
** connection with the use or performance of this software.
**
**
** $Id: emb_test.c,v 1.5 2001/12/04 03:46:29 bambi Exp $
**
*/

/*
** This is a simple program that demonstrates how an ember script can be
** embedded in a c program and used to programatically evaluate
** expressions within the c code.  There should be more error checking.
*/



#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>

#include "libember/ember.h"

char	code[]  = "$result = $x + $y; ";


int main(argc, argv)
	int	argc;
	char	*argv[];
{
	ember	*script;
	e_stab	*symbol;
	char 	*result;


	/*
	** Setup the script
	*/
	script = eCreateScript();
	eBufferSource(script, code);

	/*
	** Add the required variables to the VM
	*/
	symbol = eCreateVariable(script,"x");
	eSetIntValue(script,symbol, 10);

	symbol = eCreateVariable(script,"y");
	eSetIntValue(script,symbol, 17);


	/*
	** Parse/Compile the script reporting any errors
	*/
	if (eParseScript(script) < 0)
	{
		/* Syntax error etc */
		fprintf(stderr,"Error at line %d of script '%s'.\n",
			eGetLineNum(script), eGetSourceName(script));
		fprintf(stderr,"Error is '%s'\n\n", eGetErrorMsg(script));
		exit(1);
	}

	/*
	** Execute it ad report any errors
	*/
	if (eRunScript(script) < 0)
	{
		/* Runtime error etc */
		fprintf(stderr,"Runtime error at line %d of script '%s'.\n",
			eGetLineNum(script), eGetSourceName(script));
		fprintf(stderr,"Error is '%s'\n\n", eGetErrorMsg(script));
		exit(1);
	}


	/*
	** Grab the value of the variable called "result" from the script
	*/
	result = eGetVariableValue(script,"result");
	if (result)
		printf("\nResult = '%s'\n\n",result);

	/*
	** Demostrate calling an Ember module function from C
	*/

	if (eLoadDynamicModule(script,"mod_test") < 0)
	{
		fprintf(stderr,"Error loading module\nError is  '%s'\n\n", 
			eGetErrorMsg(script));
		exit(1);
	}


	/*
	** The ability to call ember module functions from C is only
	** partially implemented and is not yet available
	
	if (eCallFunction(script, "testFour", 0, NULL) < 0)
	{
		fprintf(stderr,"Error calling function\nError is  '%s'\n\n", 
			eGetErrorMsg(script));
		exit(1);
	}
	*/

}

==> ember-2.0.tar.gz: ember-2.0/src/ember/emb_test.c <==
/*
** Copyright (c) 2001  Hughes Technologies Pty Ltd.  All rights
** reserved.  
**
** Terms under which this software may be used or copied are
** provided in the  specific license associated with this product.
**
** Hughes Technologies disclaims all warranties with regard to this 
** software, including all implied warranties of merchantability and 
** fitness, in no event shall Hughes Technologies be liable for any 
** special, indirect or consequential damages or any damages whatsoever 
** resulting from loss of use, data or profits, whether in an action of 
** contract, negligence or other tortious action, arising out of or in 
** connection with the use or performance of this software.
**
**
** $Id: emb_test.c,v 1.5 2001/12/04 03:46:29 bambi Exp $
**
*/

/*
** This is a simple program that demonstrates how an ember script can be
** embedded in a c program and used to programatically evaluate
** expressions within the c code.  There should be more error checking.
*/



#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>
#include <sys/types.h>

#include "libember/ember.h"

char	code[]  = "$result = ($x + $y + 3) / 2; ";


int main(argc, argv)
	int	argc;
	char	*argv[];
{
	ember	*script;
	e_stab	*symbol;
	char 	*result;


	/*
	** Setup the script
	*/
	script = eCreateScript();
	eBufferSource(script, code);

	/*
	** Add the required variables to the VM
	*/
	symbol = eCreateVariable(script,"x");
	eSetIntValue(script,symbol, 10);

	symbol = eCreateVariable(script,"y");
	eSetIntValue(script,symbol, 17);


	/*
	** Parse/Compile the script reporting any errors
	*/
	if (eParseScript(script) < 0)
	{
		/* Syntax error etc */
		fprintf(stderr,"Error at line %d of script '%s'.\n",
			eGetLineNum(script), eGetSourceName(script));
		fprintf(stderr,"Error is '%s'\n\n", eGetErrorMsg(script));
		exit(1);
	}

	/*
	** Execute it and report any errors
	*/
	if (eRunScript(script) < 0)
	{
		/* Runtime error etc */
		fprintf(stderr,"Runtime error at line %d of script '%s'.\n",
			eGetLineNum(script), eGetSourceName(script));
		fprintf(stderr,"Error is '%s'\n\n", eGetErrorMsg(script));
		exit(1);
	}


	/*
	** Grab the value of the variable called "result" from the script
	*/
	result = eGetVariableValue(script,"result");
	if (result)
		printf("\nResult = '%s'\n\n",result);

	/*
	** Demostrate calling an Ember module function from C
	

	if (eLoadDynamicModule(script,"mod_test") < 0)
	{
		fprintf(stderr,"Error loading module\nError is  '%s'\n\n", 
			eGetErrorMsg(script));
		exit(1);
	}
	*/


	/*
	** The ability to call ember module functions from C is only
	** partially implemented and is not yet available
	
	if (eCallFunction(script, "testFour", 0, NULL) < 0)
	{
		fprintf(stderr,"Error calling function\nError is  '%s'\n\n", 
			eGetErrorMsg(script));
		exit(1);
	}
	*/

}
